<?xml version="1.0" ?> 
  <xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
  xmlns:nct="http://clinicaltrials.gov/show#"
  xmlns:geo="http://www.w3.org/2003/01/geo/wgs84_pos#"
  xmlns:dcterms="http://purl.org/dc/terms"
  xmlns:snomed="http://www.ihtsdo.org/"
  xmlns:xsd="http://www.w3.org/2001/XMLSchema#"
  xmlns:apdg="http://wasp.cs.vu.nl/apdg#"
  xmlns:java="http://xml.apache.org/xalan/java"
  xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
  xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
  xmlns:result="http://www.w3.org/2005/sparql-results#"
  xmlns:msxsl="urn:schemas-microsoft-com:xslt" 
  xmlns:xalan="http://xml.apache.org/xalan"
  xmlns:my-ext="nl.vua.apdg.MyExtension"
  extension-element-prefixes="my-ext"
  xmlns:dc="http://purl.org/dc/elements/1.1/">
  <xsl:output method="text" /> 
<!--  Patient2NTriple 
	Author: Zhisheng Huang 2012
	Version: 0.54
--> 

<xsl:param name="patientID"/>

<xalan:component prefix="my-ext" elements="" functions="init getVariable setVariable evaluationExp getRandomDate getElementfromSet">
 <xalan:script lang="javaclass" src="xalan://nl.vua.apdg.MyExtension"/> 
</xalan:component>

<xsl:variable name="apdg" select="string('http://wasp.cs.vu.nl/apdg#')"/>

<xsl:variable name="rdf" select="string('http://www.w3.org/1999/02/22-rdf-syntax-ns#')"/>
<xsl:variable name="rdfs" select="string('http://www.w3.org/2000/01/rdf-schema#')"/>

<xsl:variable name="xsd" select="string('http://www.w3.org/2001/XMLSchema#')"/>

<xsl:variable name="nct" select="string('http://clinicaltrials.gov/show#')"/>
<xsl:variable name="evs" select="string('http://ncicb.nci.nih.gov/xml/owl/EVS/Thesaurus.owl#')"/>
<xsl:variable name="ihtsdo" select="string('http://www.ihtsdo.org/SCT_')"/>
<xsl:variable name="hl7" select="string('http://purl.bioontology.org/ontology/HL7')"/>
<xsl:variable name="loinc" select="string('http://purl.bioontology.org/ontology/LNC')"/>
<xsl:variable name="rxnorm" select="string('http://purl.bioontology.org/ontology/RXNORM')"/>
<xsl:variable name="mesh" select="string('http://purl.bioontology.org/ontology/MSH')"/>
<xsl:variable name="geo" select="string('http://www.w3.org/2003/01/geo/wgs84_pos#')"/>

<xsl:variable name="id" select="concat($apdg,'VMR', $patientID)"/>




<xsl:template match="/root">
<xsl:apply-templates/>
</xsl:template>


<xsl:template match="Session">
<xsl:text>&lt;</xsl:text><xsl:value-of select="$id"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$rdf"/><xsl:text>type&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>VirtualMedicalRecord&gt;.
</xsl:text>

<xsl:for-each select="Archetype">
<xsl:variable name="archetypeid" select="concat($id, '_A', position())"/>


<xsl:text>&lt;</xsl:text><xsl:value-of select="$id"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>hasArchetype&gt; &lt;</xsl:text>
<xsl:value-of select="$archetypeid"/><xsl:text>&gt;.
</xsl:text>

<xsl:call-template name="archetype">
	<xsl:with-param name="archetypeid" select="$archetypeid"/>
</xsl:call-template>

</xsl:for-each>

</xsl:template>

<xsl:template name="archetype">
<xsl:param name="archetypeid"/>



<xsl:text>&lt;</xsl:text><xsl:value-of select="$archetypeid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$rdfs"/><xsl:text>label&gt; &quot;</xsl:text>
<xsl:value-of select="@concept"/><xsl:text>&quot;.
</xsl:text>

<xsl:if test="ConceptMapping/@ontology='snomed'">
<xsl:text>&lt;</xsl:text><xsl:value-of select="$archetypeid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>Concept&gt; &lt;</xsl:text>
<xsl:value-of select="$ihtsdo"/><xsl:value-of select="ConceptMapping/@conceptid"/>
<xsl:text>&gt;.
</xsl:text>
</xsl:if>


<xsl:for-each select="Slot">

<xsl:variable name="slotid" select="concat($archetypeid, 'S', position())"/>


<xsl:text>&lt;</xsl:text><xsl:value-of select="$archetypeid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>hasSlot&gt; &lt;</xsl:text>
<xsl:value-of select="$slotid"/><xsl:text>&gt;.
</xsl:text>

<xsl:call-template name="slot">
<xsl:with-param name="slotid" select="$slotid"/>


</xsl:call-template>

</xsl:for-each>


<xsl:for-each select="Variable">
<xsl:call-template name="variable">
</xsl:call-template>
</xsl:for-each>


<xsl:for-each select="EvaluationSlot">

<xsl:variable name="slotid" select="concat($archetypeid, 'S', position())"/>


<xsl:text>&lt;</xsl:text><xsl:value-of select="$archetypeid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>hasSlot&gt; &lt;</xsl:text>
<xsl:value-of select="$slotid"/><xsl:text>&gt;.
</xsl:text>

<xsl:call-template name="slot">
<xsl:with-param name="slotid" select="$slotid"/>


</xsl:call-template>

</xsl:for-each>
<!-- end of for each on EvaluationSlot -->



<xsl:for-each select="Archetype">

<xsl:variable name="archetypeid2" select="concat($archetypeid, 'A', position())"/>


<xsl:text>&lt;</xsl:text><xsl:value-of select="$archetypeid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>hasArchetype&gt; &lt;</xsl:text>
<xsl:value-of select="$archetypeid2"/><xsl:text>&gt;.
</xsl:text>

<xsl:call-template name="archetype">
<xsl:with-param name="archetypeid" select="$archetypeid2"/>

</xsl:call-template>

</xsl:for-each>


</xsl:template>



<xsl:template name="variable">
<xsl:for-each select="Distributions">
<xsl:variable name="vtype" select="@type"/>
<xsl:variable name="vvariable" select="@variable"/>

<xsl:if test="$vtype='string'">

<xsl:call-template name="variable-distribution-string">
<xsl:with-param name="vvariable" select="$vvariable"/>
</xsl:call-template>
</xsl:if>

</xsl:for-each>

</xsl:template>


<xsl:template name="variable-distribution-string">
<xsl:param name="vvariable"/>

<xsl:variable name="rnd">
<xsl:value-of select="java:java.lang.Math.random()*100"/>
</xsl:variable>

<xsl:for-each select="Distribution">

<xsl:if test="@pfrom and @pto">
<xsl:variable name="pfrom" select="@pfrom"/>
<xsl:variable name="pto" select="@pto"/>

<xsl:if test="@condition">
<xsl:variable name="expression" select="@condition"/>
<xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))"/>

<xsl:if test="$evaluation = 'true' and $pfrom &lt;= $rnd and $rnd &lt; $pto">

<xsl:if test="parent::*/@variable">
<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="@item"/>
<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#Expression variable </xsl:text>
<xsl:value-of select="$expressionvariable"/>=<xsl:value-of select="$variablevalue"/><xsl:text> has been set.
</xsl:text>
</xsl:if>
</xsl:if>
</xsl:if>

<xsl:if test="not(@condition)">
<xsl:if test="$pfrom &lt;= $rnd and $rnd &lt; $pto">

<xsl:if test="parent::*/@variable">
<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="@item"/>
<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#  Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/><xsl:text> has been set.
</xsl:text>
</xsl:if>
</xsl:if>
</xsl:if>

</xsl:if>
<!-- end of if test at pfrom and pto -->


<xsl:if test="@disttype and not(@condition)">
<xsl:variable name="disttype" select="@disttype"/>
<xsl:variable name="datatype" select="@datatype"/>
<xsl:variable name="data" select="@data"/>
<xsl:variable name="elementvalue" select="my-ext:getElementfromSet($disttype, $datatype, $data, $rnd)"/>

<xsl:if test="parent::*/@variable">
<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="$elementvalue"/>
<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#  Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/><xsl:text> has been set.
</xsl:text>
</xsl:if>

</xsl:if>
<!-- end of disttype and not condition -->



<xsl:if test="@disttype and @condition">

<xsl:variable name="expression" select="@condition"/>
<xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))"/>

<xsl:if test="$evaluation = 'true'">

<xsl:variable name="disttype" select="@disttype"/>
<xsl:variable name="datatype" select="@datatype"/>
<xsl:variable name="data" select="@data"/>
<xsl:variable name="elementvalue" select="my-ext:getElementfromSet($disttype, $datatype, $data, $rnd)"/>

<xsl:if test="parent::*/@variable">
<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="$elementvalue"/>
<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#  Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/><xsl:text> has been set.
</xsl:text>
</xsl:if>

</xsl:if>
<!-- end of if test on evaluation -->
</xsl:if>
<!-- end of disttype and condition -->


</xsl:for-each>

</xsl:template>
<!-- end of variable-distribution-string template -->

<xsl:template name="slot">
<xsl:param name="slotid"/>


<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$rdfs"/><xsl:text>label&gt; &quot;</xsl:text>
<xsl:value-of select="@value"/><xsl:text>&quot;.
</xsl:text>

<xsl:if test="ConceptMapping/@ontology='snomed'">
<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>Concept&gt; &lt;</xsl:text>
<xsl:value-of select="$ihtsdo"/><xsl:value-of select="ConceptMapping/@conceptid"/>
<xsl:text>&gt;.
</xsl:text>
</xsl:if>

<xsl:if test="@source='system:patientID'">
<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$patientID"/>
<xsl:text>&quot;.
</xsl:text>
</xsl:if>


<xsl:if test="starts-with(@source,'concat')">

<xsl:variable name="concatexp" select="@source"/>

<xsl:variable name="concatexp-value" select="my-ext:concatExp(string(@source))" />

<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$concatexp-value"/>
<xsl:text>&quot;.
</xsl:text>

</xsl:if>

<xsl:call-template name="distributions">
<xsl:with-param name="slotid" select="$slotid"/>
</xsl:call-template>


</xsl:template>

<xsl:template name="distributions">
<xsl:param name="slotid"/> 


<xsl:for-each select="DataRange/Distributions">

<xsl:if test="@if">


<xsl:variable name="expression" select="@if"/>
<xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))" />

<!-- ***<xsl:value-of select="$evaluation"/>*** -->
<xsl:if test="$evaluation='true'">
<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="@then"/>
<xsl:text>&quot;.
</xsl:text>
</xsl:if>

<xsl:if test="not($evaluation='true')">

<xsl:call-template name="distribution">
<xsl:with-param name="slotid" select="$slotid"/>
</xsl:call-template>

</xsl:if>

</xsl:if>

<xsl:if test="not(@if)">

<xsl:call-template name="distribution">
<xsl:with-param name="slotid" select="$slotid"/>
</xsl:call-template>

</xsl:if>

</xsl:for-each>

</xsl:template>

<xsl:template name="distribution">
<xsl:param name="slotid"/>


<xsl:variable name="dtype" select="@type"/>
<xsl:variable name="dunit" select="@unit"/>

<xsl:if test="$dtype='enumeration'">

<xsl:call-template name="distribution-enumeration">
<xsl:with-param name="slotid" select="$slotid"/>
</xsl:call-template>
</xsl:if>

<xsl:if test="$dtype='float'">
<xsl:call-template name="distribution-float"> 
<xsl:with-param name="slotid" select="$slotid"/>
</xsl:call-template>
</xsl:if>

<xsl:if test="$dtype='date'">
<xsl:call-template name="distribution-date"> 
<xsl:with-param name="slotid" select="$slotid"/>
</xsl:call-template>
</xsl:if>

<xsl:if test="$dtype='year'">
<xsl:call-template name="distribution-year"> 
<xsl:with-param name="slotid" select="$slotid"/>
</xsl:call-template>
</xsl:if>

</xsl:template>

<xsl:template name="distribution-enumeration">
<xsl:param name="slotid"/>

<xsl:variable name="rnd">
        <xsl:value-of select="java:java.lang.Math.random()*100"
		xmlns:java="http://xml.apache.org/xalan/java"/>
         </xsl:variable>



<xsl:for-each select="Distribution">

<xsl:if test="@pfrom and @pto">
<xsl:variable name="pfrom" select="@pfrom"/>
<xsl:variable name="pto" select="@pto"/>


<xsl:if test="@condition">

<xsl:variable name="expression" select="@condition"/>
<xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))" />


<xsl:if test="$evaluation = 'true' and $pfrom &lt;= $rnd and $rnd &lt; $pto">


<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="@item"/><xsl:text>&quot;.
</xsl:text>


<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="@item"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/>=<xsl:value-of select="$variablevalue"/><xsl:text> has been set.
</xsl:text>

</xsl:if>

</xsl:if>

</xsl:if>

<xsl:if test="not(@condition)">

<xsl:if test="$pfrom &lt;= $rnd and $rnd &lt; $pto">


<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="@item"/><xsl:text>&quot;.
</xsl:text>


<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="@item"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#  Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/><xsl:text> has been set.
</xsl:text>
</xsl:if>

</xsl:if>

</xsl:if>

</xsl:if>
<!-- end of if test at pfrom and pto -->



<xsl:if test="@disttype and not(@condition)">

<xsl:variable name="disttype" select="@disttype"/>
<xsl:variable name="datatype" select="@datatype"/>
<xsl:variable name="data" select="@data"/>

<xsl:variable name="elementvalue" select="my-ext:getElementfromSet($disttype, $datatype, $data, $rnd)"/>


<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$elementvalue"/><xsl:text>&quot;.
</xsl:text>

<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="string($elementvalue)"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/>=<xsl:value-of select="$variablevalue"/><xsl:text> has been set.
</xsl:text>
</xsl:if>

</xsl:if>
<!-- end of disttype and not condition -->


<xsl:if test="@disttype and @condition">

<xsl:variable name="expression" select="@condition"/>
<xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))" />

<xsl:if test="$evaluation = 'true'">


<xsl:variable name="disttype" select="@disttype"/>
<xsl:variable name="datatype" select="@datatype"/>
<xsl:variable name="data" select="@data"/>

<xsl:variable name="elementvalue" select="my-ext:getElementfromSet($disttype, $datatype, $data, $rnd)"/>


<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$elementvalue"/><xsl:text>&quot;.
</xsl:text>

<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="string($elementvalue)"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/>=<xsl:value-of select="$variablevalue"/><xsl:text> has been set.
</xsl:text>
</xsl:if>


</xsl:if>
<!-- end of if test on evaluation -->



</xsl:if>
<!-- end of disttype and condition -->

</xsl:for-each>
</xsl:template>

<xsl:template name="distribution-float">
<xsl:param name="slotid"/>

<xsl:variable name="rnd">
        <xsl:value-of select="java:java.lang.Math.random()*100"
		xmlns:java="http://xml.apache.org/xalan/java"/>
         </xsl:variable>


<xsl:for-each select="Distribution">

<xsl:variable name="pfrom" select="@pfrom"/>
<xsl:variable name="pto" select="@pto"/>

<xsl:variable name="dtype" select="parent::*/@type"/>
<xsl:variable name="dunit" select="parent::*/@unit"/>

<!-- begin if test -->
<xsl:if test="@condition">
<xsl:variable name="expression" select="@condition"/>
<xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))" />


<xsl:if test="$evaluation = 'true' and $pfrom &lt;= $rnd and $rnd &lt; $pto">



<xsl:variable name="rnd0">
        <xsl:value-of select="java:java.lang.Math.random()"
		xmlns:java="http://xml.apache.org/xalan/java"/>
         </xsl:variable>

<xsl:variable name="dvalue" select="round((number(@from) + (number(@to)-number(@from))*$rnd0)*10) div 10"/>

<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$dvalue"/><xsl:text>&quot;^^&lt;</xsl:text><xsl:value-of select="$xsd"/>
<xsl:text>decimal&gt;.
</xsl:text>


<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>unit&gt; &quot;</xsl:text>
<xsl:value-of select="$dunit"/><xsl:text>&quot;.
</xsl:text>


<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="string($dvalue)"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#  Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/><xsl:text> has been set.
</xsl:text>
</xsl:if>

</xsl:if>

</xsl:if>
<!-- end if test -->




<!-- begin if test -->
<xsl:if test="not(@condition)">

<xsl:if test="$pfrom &lt;= $rnd and $rnd &lt; $pto">



<xsl:variable name="rnd0">
        <xsl:value-of select="java:java.lang.Math.random()"
		xmlns:java="http://xml.apache.org/xalan/java"/>
         </xsl:variable>

<xsl:variable name="dvalue" select="round((number(@from) + (number(@to)-number(@from))*$rnd0)*10) div 10"/>

<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$dvalue"/><xsl:text>&quot;^^&lt;</xsl:text><xsl:value-of select="$xsd"/>
<xsl:text>decimal&gt;.
</xsl:text>


<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>unit&gt; &quot;</xsl:text>
<xsl:value-of select="$dunit"/><xsl:text>&quot;.
</xsl:text>


<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="string($dvalue)"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#  Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/><xsl:text> has been set.
</xsl:text>
</xsl:if>

</xsl:if>
</xsl:if>
<!-- end if test on pfrom and pto-->


<xsl:if test="@disttype and not(@condition)">

<xsl:variable name="disttype" select="@disttype"/>
<xsl:variable name="datatype" select="@datatype"/>
<xsl:variable name="data" select="@data"/>

<xsl:variable name="elementvalue" select="my-ext:getElementfromSet($disttype, $datatype, $data, $rnd)"/>


<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$elementvalue"/><xsl:text>&quot;^^&lt;</xsl:text><xsl:value-of select="$xsd"/>
<xsl:text>decimal&gt;.
</xsl:text>

<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="string($elementvalue)"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/>=<xsl:value-of select="$variablevalue"/><xsl:text> has been set.
</xsl:text>
</xsl:if>

</xsl:if>
<!-- end of disttype and not condition -->


<xsl:if test="@disttype and @condition">

<xsl:variable name="expression" select="@condition"/>
<xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))" />

<xsl:if test="$evaluation = 'true'">


<xsl:variable name="disttype" select="@disttype"/>
<xsl:variable name="datatype" select="@datatype"/>
<xsl:variable name="data" select="@data"/>

<xsl:variable name="elementvalue" select="my-ext:getElementfromSet($disttype, $datatype, $data, $rnd)"/>


<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$elementvalue"/><xsl:text>&quot;^^&lt;</xsl:text><xsl:value-of select="$xsd"/>
<xsl:text>decimal&gt;.
</xsl:text>

<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="string($elementvalue)"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/>=<xsl:value-of select="$variablevalue"/><xsl:text> has been set.
</xsl:text>
</xsl:if>


</xsl:if>
<!-- end of if test on evaluation -->



</xsl:if>
<!-- end of disttype and condition -->

</xsl:for-each>

</xsl:template>

<xsl:template name="distribution-date">
<xsl:param name="slotid"/>

<xsl:variable name="rnd">
        <xsl:value-of select="java:java.lang.Math.random()*100"
		xmlns:java="http://xml.apache.org/xalan/java"/>
         </xsl:variable>


<xsl:for-each select="Distribution">

<xsl:variable name="pfrom" select="@pfrom"/>
<xsl:variable name="pto" select="@pto"/>

<!-- begin of if test-->
<xsl:if test="@condition">
<xsl:variable name="expression" select="@condition"/>
<xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))" />


<xsl:if test="$evaluation = 'true' and $pfrom &lt;= $rnd and $rnd &lt; $pto">

<xsl:variable name="ddate" select="my-ext:getRandomDate(string(@from),string(@to))" />



<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$ddate"/><xsl:text>&quot;.
</xsl:text>


<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="$ddate"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#  Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/><xsl:text> has been set.
</xsl:text>
</xsl:if>

</xsl:if>
</xsl:if>
<!-- end of if test -->

<!-- begin of if test-->
<xsl:if test="not(@condition)">
<xsl:if test="$pfrom &lt;= $rnd and $rnd &lt; $pto">

<xsl:variable name="ddate" select="my-ext:getRandomDate(string(@from),string(@to))" />



<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$ddate"/><xsl:text>&quot;.
</xsl:text>


<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="$ddate"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#  Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/><xsl:text> has been set.
</xsl:text>
</xsl:if>

</xsl:if>

</xsl:if>
<!-- end of if test on pfrom and pto -->



<xsl:if test="@disttype and not(@condition)">

<xsl:variable name="disttype" select="@disttype"/>
<xsl:variable name="datatype" select="@datatype"/>
<xsl:variable name="data" select="@data"/>

<xsl:variable name="elementvalue" select="my-ext:getElementfromSet($disttype, $datatype, $data, $rnd)"/>


<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$elementvalue"/><xsl:text>&quot;^^&lt;</xsl:text><xsl:value-of select="$xsd"/>
<xsl:text>integer&gt;.
</xsl:text>

<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="string($elementvalue)"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/>=<xsl:value-of select="$variablevalue"/><xsl:text> has been set.
</xsl:text>
</xsl:if>

</xsl:if>
<!-- end of disttype and not condition -->


<xsl:if test="@disttype and @condition">

<xsl:variable name="expression" select="@condition"/>
<xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))" />

<xsl:if test="$evaluation = 'true'">


<xsl:variable name="disttype" select="@disttype"/>
<xsl:variable name="datatype" select="@datatype"/>
<xsl:variable name="data" select="@data"/>

<xsl:variable name="elementvalue" select="my-ext:getElementfromSet($disttype, $datatype, $data, $rnd)"/>


<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$elementvalue"/><xsl:text>&quot;^^&lt;</xsl:text><xsl:value-of select="$xsd"/>
<xsl:text>integer&gt;.
</xsl:text>

<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="string($elementvalue)"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/>=<xsl:value-of select="$variablevalue"/><xsl:text> has been set.
</xsl:text>
</xsl:if>


</xsl:if>
<!-- end of if test on evaluation -->



</xsl:if>
<!-- end of disttype and condition -->

</xsl:for-each>
</xsl:template>

<xsl:template name="distribution-year">
<xsl:param name="slotid"/>

<xsl:variable name="rnd">
        <xsl:value-of select="java:java.lang.Math.random()*100"
		xmlns:java="http://xml.apache.org/xalan/java"/>
         </xsl:variable>


<xsl:for-each select="Distribution">

<xsl:variable name="pfrom" select="@pfrom"/>
<xsl:variable name="pto" select="@pto"/>

<xsl:if test="@condition">

<xsl:variable name="expression" select="@condition"/>
<xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))" />


<xsl:if test="$evaluation = 'true' and $pfrom &lt;= $rnd and $rnd &lt; $pto">


<xsl:variable name="rnd0">
        <xsl:value-of select="java:java.lang.Math.random()"
		xmlns:java="http://xml.apache.org/xalan/java"/>
         </xsl:variable>

<xsl:variable name="dvalue" select="round(number(@from) + (number(@to)-number(@from))*$rnd0)"/>

<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$dvalue"/><xsl:text>&quot;^^&lt;</xsl:text><xsl:value-of select="$xsd"/>
<xsl:text>integer&gt;.
</xsl:text>



<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="string($dvalue)"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/>=<xsl:value-of select="$variablevalue"/><xsl:text> has been set.
</xsl:text>
</xsl:if>

</xsl:if>
</xsl:if>

<xsl:if test="not(@condition)">
<xsl:if test="$pfrom &lt;= $rnd and $rnd &lt; $pto">



<xsl:variable name="rnd0">
        <xsl:value-of select="java:java.lang.Math.random()"
		xmlns:java="http://xml.apache.org/xalan/java"/>
         </xsl:variable>

<xsl:variable name="dvalue" select="round(number(@from) + (number(@to)-number(@from))*$rnd0)"/>

<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$dvalue"/><xsl:text>&quot;^^&lt;</xsl:text><xsl:value-of select="$xsd"/>
<xsl:text>integer&gt;.
</xsl:text>



<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="string($dvalue)"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/>=<xsl:value-of select="$variablevalue"/><xsl:text> has been set.
</xsl:text>
</xsl:if>

</xsl:if>

</xsl:if>
<!--end of if test on pfrom and pto -->

<xsl:if test="@disttype and not(@condition)">

<xsl:variable name="disttype" select="@disttype"/>
<xsl:variable name="datatype" select="@datatype"/>
<xsl:variable name="data" select="@data"/>

<xsl:variable name="elementvalue" select="my-ext:getElementfromSet($disttype, $datatype, $data, $rnd)"/>


<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$elementvalue"/><xsl:text>&quot;^^&lt;</xsl:text><xsl:value-of select="$xsd"/>
<xsl:text>integer&gt;.
</xsl:text>

<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="string($elementvalue)"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/>=<xsl:value-of select="$variablevalue"/><xsl:text> has been set.
</xsl:text>
</xsl:if>

</xsl:if>
<!-- end of disttype and not condition -->


<xsl:if test="@disttype and @condition">

<xsl:variable name="expression" select="@condition"/>
<xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))" />

<xsl:if test="$evaluation = 'true'">


<xsl:variable name="disttype" select="@disttype"/>
<xsl:variable name="datatype" select="@datatype"/>
<xsl:variable name="data" select="@data"/>

<xsl:variable name="elementvalue" select="my-ext:getElementfromSet($disttype, $datatype, $data, $rnd)"/>


<xsl:text>&lt;</xsl:text><xsl:value-of select="$slotid"/><xsl:text>&gt; &lt;</xsl:text>
<xsl:value-of select="$apdg"/><xsl:text>value&gt; &quot;</xsl:text>
<xsl:value-of select="$elementvalue"/><xsl:text>&quot;^^&lt;</xsl:text><xsl:value-of select="$xsd"/>
<xsl:text>integer&gt;.
</xsl:text>

<xsl:if test="parent::*/@variable">

<xsl:variable name="variablename" select="parent::*/@variable"/>
<xsl:variable name="variablevalue" select="string($elementvalue)"/>

<xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
<xsl:text>#Expression variable </xsl:text><xsl:value-of select="$expressionvariable"/>=<xsl:value-of select="$variablevalue"/><xsl:text> has been set.
</xsl:text>
</xsl:if>


</xsl:if>
<!-- end of if test on evaluation -->



</xsl:if>
<!-- end of disttype and condition -->


</xsl:for-each>

</xsl:template>



</xsl:stylesheet>
