<?xml version="1.0" ?> 
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" xmlns:java="http://xml.apache.org/xalan/java"
        xmlns:xalan="http://xml.apache.org/xalan" xmlns:my-ext="nl.vua.apdg.MyExtension" extension-element-prefixes="my-ext">
        <xsl:param name="patientID"/>
        <xalan:component prefix="my-ext" elements="" functions="init getVariable setVariable evaluationExp getRandomDate">
                <xalan:script lang="javaclass" src="xalan://nl.vua.apdg.MyExtension"/>
        </xalan:component>
        <xsl:variable name="apdg" select="string('http://wasp.cs.vu.nl/apdg#')"/>
        <xsl:variable name="id" select="concat($apdg,'VMR', $patientID)"/>
        <xsl:strip-space  elements="*"/>
        <!--  Patient2xml
	Authors: Jose Alberto Maldonado & Zhisheng Huang 2012
	Version: 0.2
--> 
        
        <xsl:template match="/root">
                <root><xsl:apply-templates/></root>
        </xsl:template>
        
        <xsl:template match="Session">
                <session>
                        <xsl:for-each select="Archetype">
                                <xsl:call-template name="archetype"/>
                        </xsl:for-each>
                </session>
        </xsl:template>

        <xsl:template name="archetype">
                <xsl:element name="{@concept}">
                        <xsl:if test="ConceptMapping/@ontology and ConceptMapping/@conceptid">
                                <xsl:attribute name="ontology">
                                        <xsl:value-of select="ConceptMapping/@ontology"/>
                                </xsl:attribute>
                                <xsl:attribute name="codeValue">
                                        <xsl:value-of select="ConceptMapping/@conceptid"/>
                                </xsl:attribute>
                        </xsl:if>
                        <xsl:for-each select="Slot">
                                <xsl:call-template name="slot"/>
                        </xsl:for-each>
                        <xsl:for-each select="Archetype">
                                <xsl:call-template name="archetype"/>
                        </xsl:for-each>
                </xsl:element>
        </xsl:template>


        <xsl:template name="slot">
                <xsl:element name="{@value}">
                        <xsl:if test="ConceptMapping/@ontology and ConceptMapping/@conceptid">
                                <xsl:attribute name="ontology">
                                        <xsl:value-of select="ConceptMapping/@ontology"/>
                                </xsl:attribute>
                                <xsl:attribute name="codeValue">
                                        <xsl:value-of select="ConceptMapping/@conceptid"/>
                                </xsl:attribute>
                        </xsl:if>

                        <xsl:if test="@source='system:patientID'">
                                <xsl:value-of select="$patientID"/>
                        </xsl:if>
                        <xsl:call-template name="distributions"/>
                </xsl:element>
        </xsl:template>

        <xsl:template name="distributions">
                <xsl:for-each select="DataRange/Distributions">
                        <xsl:if test="@if">
                                <xsl:variable name="expression" select="@if"/>
                                <xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))"/>
                                <!-- ***<xsl:value-of select="$evaluation"/>*** -->
                                <xsl:if test="$evaluation='true'">
                                        <xsl:value-of select="@then"/>
                                </xsl:if>
                                <xsl:if test="not($evaluation='true')">
                                        <xsl:call-template name="distribution"> </xsl:call-template>
                                </xsl:if>
                        </xsl:if>
                        <xsl:if test="not(@if)">
                                <xsl:call-template name="distribution"> </xsl:call-template>
                        </xsl:if>
                </xsl:for-each>
        </xsl:template>

        <xsl:template name="distribution">
                <xsl:variable name="dtype" select="@type"/>
                <xsl:variable name="dunit" select="@unit"/>

                <xsl:if test="$dtype='enumeration'">
                        <xsl:call-template name="distribution-enumeration"/>
                </xsl:if>
                <xsl:if test="$dtype='float'">
                        <xsl:call-template name="distribution-float"/>
                </xsl:if>
                <xsl:if test="$dtype='date'">
                        <xsl:call-template name="distribution-date"/>
                </xsl:if>
                <xsl:if test="$dtype='year'">
                        <xsl:call-template name="distribution-year"/>
                </xsl:if>
        </xsl:template>

        <xsl:template name="distribution-enumeration">
                <xsl:variable name="rnd">
                        <xsl:value-of select="java:java.lang.Math.random()*100" xmlns:java="http://xml.apache.org/xalan/java"/>
                </xsl:variable>
                <xsl:for-each select="Distribution">
                        <xsl:variable name="pfrom" select="@pfrom"/>
                        <xsl:variable name="pto" select="@pto"/>
                        <xsl:if test="@condition">
                                <xsl:variable name="expression" select="@condition"/>
                                <xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))"/>
                                <xsl:variable name="valor" select="my-ext:evaluationExp('$birthyear')"/>
                                        
                                <xsl:if test="$evaluation = 'true' and $pfrom &lt;= $rnd and $rnd &lt; $pto">
                                        <xsl:value-of select="@item"/>
                                        <xsl:if test="parent::*/@variable">
                                                <xsl:variable name="variablename"  select="parent::*/@variable"/>
                                                <xsl:variable name="variablevalue" select="@item"/>
                                                <xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
                                        </xsl:if>
                                </xsl:if>
                        </xsl:if>
                        <xsl:if test="not(@condition)">
                                <xsl:if test="$pfrom &lt;= $rnd and $rnd &lt; $pto">
                                        <xsl:value-of select="@item"/>
                                        <xsl:if test="parent::*/@variable">
                                                <xsl:variable name="variablename" select="parent::*/@variable"/>
                                                <xsl:variable name="variablevalue" select="@item"/>
                                                <xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>                                            
                                        </xsl:if>
                                </xsl:if>
                        </xsl:if>
                </xsl:for-each>
        </xsl:template>

        <xsl:template name="distribution-float">
                <xsl:variable name="rnd">
                        <xsl:value-of select="java:java.lang.Math.random()*100" xmlns:java="http://xml.apache.org/xalan/java"/>
                </xsl:variable>
                <xsl:for-each select="Distribution">
                        <xsl:variable name="pfrom" select="@pfrom"/>
                        <xsl:variable name="pto" select="@pto"/>
                        <xsl:variable name="dtype" select="parent::*/@type"/>
                        <xsl:variable name="dunit" select="parent::*/@unit"/>
                        
                        <!-- begin if test -->
                        <xsl:if test="@condition">
                                <xsl:variable name="expression" select="@condition"/>
                                <xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))"/>
                                <xsl:if test="$evaluation = 'true' and $pfrom &lt;= $rnd and $rnd &lt; $pto">
                                        <xsl:variable name="rnd0">
                                                <xsl:value-of select="java:java.lang.Math.random()" xmlns:java="http://xml.apache.org/xalan/java"/>
                                        </xsl:variable>
                                        <xsl:attribute name="unit">
                                                <xsl:value-of select="$dunit"/>
                                        </xsl:attribute>
                                        <xsl:variable name="dvalue" select="round((number(@from) + (number(@to)-number(@from))*$rnd0)*10) div 10"/>
                                        <xsl:value-of select="$dvalue"/>
                                       
                                        <xsl:if test="parent::*/@variable">
                                                <xsl:variable name="variablename" select="parent::*/@variable"/>
                                                <xsl:variable name="variablevalue" select="string($dvalue)"/>
                                                <xsl:variable name="expressionvariable"  select="my-ext:setVariable($variablename, $variablevalue)"/>
                                       </xsl:if>
                                </xsl:if>
                        </xsl:if>
                        <!-- end if test -->

                        <!-- begin if test -->
                        <xsl:if test="not(@condition)">
                                <xsl:if test="$pfrom &lt;= $rnd and $rnd &lt; $pto">
                                        <xsl:variable name="rnd0">
                                                <xsl:value-of select="java:java.lang.Math.random()"  xmlns:java="http://xml.apache.org/xalan/java"/>
                                        </xsl:variable>
                                        <xsl:variable name="dvalue" select="round((number(@from) + (number(@to)-number(@from))*$rnd0)*10) div 10"/>
                                        <xsl:element name="value">
                                                <xsl:value-of select="$dvalue"/>
                                        </xsl:element>
                                        <xsl:element name="unit">
                                                <xsl:value-of select="$dunit"/>
                                        </xsl:element>
                                        <xsl:if test="parent::*/@variable">
                                                <xsl:variable name="variablename" select="parent::*/@variable"/>
                                                <xsl:variable name="variablevalue" select="string($dvalue)"/>
                                                <xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
                                        </xsl:if>
                                </xsl:if>
                        </xsl:if>
                        <!-- end if test -->
                </xsl:for-each>
        </xsl:template>

        <xsl:template name="distribution-date">
                <xsl:variable name="rnd">
                        <xsl:value-of select="java:java.lang.Math.random()*100" xmlns:java="http://xml.apache.org/xalan/java"/>
                </xsl:variable>
                <xsl:for-each select="Distribution">

                        <xsl:variable name="pfrom" select="@pfrom"/>
                        <xsl:variable name="pto" select="@pto"/>

                        <!-- begin of if test-->
                        <xsl:if test="@condition">
                                <xsl:variable name="expression" select="@condition"/>
                                <xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))"/>
                                <xsl:if test="$evaluation = 'true' and $pfrom &lt;= $rnd and $rnd &lt; $pto">
                                        <xsl:variable name="ddate" select="my-ext:getRandomDate(string(@from),string(@to))"/>
                                        <xsl:value-of select="$ddate"/>
                                        <xsl:if test="parent::*/@variable">
                                                <xsl:variable name="variablename"  select="parent::*/@variable"/>
                                                <xsl:variable name="variablevalue" select="$ddate"/>
                                                <xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
                                        </xsl:if>
                                </xsl:if>
                        </xsl:if>
                        <!-- end of if test -->

                        <!-- begin of if test-->
                        <xsl:if test="not(@condition)">
                                <xsl:if test="$pfrom &lt;= $rnd and $rnd &lt; $pto">
                                        <xsl:variable name="ddate" select="my-ext:getRandomDate(string(@from),string(@to))"/>
                                        <xsl:value-of select="$ddate"/>
                                        <xsl:if test="parent::*/@variable">
                                                <xsl:variable name="variablename" select="parent::*/@variable"/>
                                                <xsl:variable name="variablevalue" select="$ddate"/>
                                                <xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
                                        </xsl:if>
                                </xsl:if>
                        </xsl:if>
                        <!-- end of if test -->
                </xsl:for-each>
        </xsl:template>

        <xsl:template name="distribution-year">
                <xsl:variable name="rnd">
                        <xsl:value-of select="java:java.lang.Math.random()*100" xmlns:java="http://xml.apache.org/xalan/java"/>
                </xsl:variable>
             
                <xsl:for-each select="Distribution">
                        <xsl:variable name="pfrom" select="@pfrom"/>
                        <xsl:variable name="pto" select="@pto"/>
                        <xsl:if test="@condition">
                                <xsl:variable name="expression" select="@condition"/>
                                <xsl:variable name="evaluation" select="my-ext:evaluationExp(string($expression))"/>
                                <xsl:if test="$evaluation = 'true' and $pfrom &lt;= $rnd and $rnd &lt; $pto">
                                        <xsl:variable name="rnd0">
                                                <xsl:value-of select="java:java.lang.Math.random()" xmlns:java="http://xml.apache.org/xalan/java"/>
                                        </xsl:variable>

                                        <xsl:variable name="dvalue" select="round(number(@from) + (number(@to)-number(@from))*$rnd0)"/>
                                        <xsl:value-of select="$dvalue"/>
                                        <xsl:if test="parent::*/@variable">
                                                <xsl:variable name="variablename" select="parent::*/@variable"/>
                                                <xsl:variable name="variablevalue" select="string($dvalue)"/>
                                                <xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>
                                        </xsl:if>
                                </xsl:if>
                        </xsl:if>

                        <xsl:if test="not(@condition)">
                                <xsl:if test="$pfrom &lt;= $rnd and $rnd &lt; $pto">
                                        <xsl:variable name="rnd0">
                                                <xsl:value-of select="java:java.lang.Math.random()" xmlns:java="http://xml.apache.org/xalan/java"/>
                                        </xsl:variable>
                                        <xsl:variable name="dvalue" select="round(number(@from) + (number(@to)-number(@from))*$rnd0)"/>
                                        <xsl:value-of select="$dvalue"/>
                                        <xsl:if test="parent::*/@variable">
                                                <xsl:variable name="variablename" select="parent::*/@variable"/>
                                                <xsl:variable name="variablevalue" select="string($dvalue)"/>
                                                <xsl:variable name="expressionvariable" select="my-ext:setVariable($variablename, $variablevalue)"/>                                           
                                        </xsl:if>
                                </xsl:if>
                        </xsl:if>
                </xsl:for-each>
        </xsl:template>
</xsl:stylesheet>
